Type Alias sg721_base::QueryMsg

source ·
pub type QueryMsg = QueryMsg<Empty>;

Aliased Type

enum QueryMsg {
Show 14 variants OwnerOf { token_id: String, include_expired: Option<bool>, }, Approval { token_id: String, spender: String, include_expired: Option<bool>, }, Approvals { token_id: String, include_expired: Option<bool>, }, Operator { owner: String, operator: String, include_expired: Option<bool>, }, AllOperators { owner: String, include_expired: Option<bool>, start_after: Option<String>, limit: Option<u32>, }, NumTokens {}, ContractInfo {}, NftInfo { token_id: String, }, AllNftInfo { token_id: String, include_expired: Option<bool>, }, Tokens { owner: String, start_after: Option<String>, limit: Option<u32>, }, AllTokens { start_after: Option<String>, limit: Option<u32>, }, Minter {}, Extension { msg: Empty, }, Ownership {},
}

Variants



OwnerOf

Fields

token_id: String
include_expired: Option<bool>

unset or false will filter out expired approvals, you must set to true to see them

Return the owner of the given token, error if token does not exist



Approval

Fields

token_id: String
spender: String
include_expired: Option<bool>

Return operator that can access all of the owner’s tokens.



Approvals

Fields

token_id: String
include_expired: Option<bool>

Return approvals that a token has



Operator

Fields

owner: String
operator: String
include_expired: Option<bool>

Return approval of a given operator for all tokens of an owner, error if not set



AllOperators

Fields

owner: String
include_expired: Option<bool>

unset or false will filter out expired items, you must set to true to see them

start_after: Option<String>
limit: Option<u32>

List all operators that can access all of the owner’s tokens



NumTokens

Fields

Total number of tokens issued



ContractInfo

Fields

With MetaData Extension. Returns top-level metadata about the contract



NftInfo

Fields

token_id: String

With MetaData Extension. Returns metadata about one particular token, based on ERC721 Metadata JSON Schema but directly from the contract



AllNftInfo

Fields

token_id: String
include_expired: Option<bool>

unset or false will filter out expired approvals, you must set to true to see them

With MetaData Extension. Returns the result of both NftInfo and OwnerOf as one query as an optimization for clients



Tokens

Fields

owner: String
start_after: Option<String>
limit: Option<u32>

With Enumerable extension. Returns all tokens owned by the given address, [] if unset.



AllTokens

Fields

start_after: Option<String>
limit: Option<u32>

With Enumerable extension. Requires pagination. Lists all token_ids controlled by the contract.



Minter

Fields

Return the minter



Extension

Fields

msg: Empty

Extension query



Ownership

Fields

Query the contract’s ownership information